OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Завантаження попереднього перегляду...",
    "Admin" : "Адмін",
    "Saved" : "Збережено",
    "a safe home for all your data" : "безпечна домівка для ваших даних",
    "Error uploading the file" : "Помилка завантаження файлу",
    "Name cannot be empty" : "Ім'я не може бути порожнім",
    "The given name is too long" : "Ім'я задовге",
    "The given web address is too long" : "Вебадреса занадто довга",
    "The given web address is not a valid URL" : "Зазначена вебадреса не є правильним посиланням",
    "The given legal notice address is too long" : "Зазначена адреса з правовою інформацією задовга",
    "The given legal notice address is not a valid URL" : "Зазначена адреса з правовою інформацією не є правильним посиланням",
    "The given privacy policy address is too long" : "Зазначена адреса з інформацією про конфіденційність задовга",
    "The given privacy policy address is not a valid URL" : "Зазначена адреса з інформацією про конфіденційність не є правильним посиланням",
    "The given slogan is too long" : "Зазначене гасло є задовгим",
    "The given color is invalid" : "Зазначений колір є неправильним",
    "The file was uploaded" : "Файл завантажено",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Файл для завантаження перевищує параметр upload_max_filesize у php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Розмір завантаженого файлу перевищує директиву MAX_FILE_SIZE, зазначену у HTML-формі",
    "The file was only partially uploaded" : "Файл завантажено лише частково",
    "No file was uploaded" : "Не вивантажено жодного файлу",
    "Missing a temporary folder" : "Відсутня тимчасова тека",
    "Could not write file to disk" : "Неможливо записати файл на диск",
    "A PHP extension stopped the file upload" : "Розширення PHP призупинило завантаження файлу",
    "No file uploaded" : "Файл не завантажено",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Ви уже використовуєте власну тему. Таким чином налаштування застосунку Оформлення може бути перезаписано.",
    "Theming" : "Оформлення",
    "Dark theme" : "Темна тема",
    "Enable dark theme" : "Увімкнути темну тему",
    "Dyslexia font" : "Шрифт для людей, які страждають від дислексії",
    "Enable dyslexia font" : "Увімкнути шрифт для людей, які страждають від дислексії",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic - це вільно доступний шрифт, що було розроблено для уникнення деяких загальних помилок, що спричинені дизлексією.",
    "High contrast mode" : "Висококонтрастний режим",
    "Enable high contrast mode" : "Увімкнути висококонтрастний режим",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Висококонтрастний режим спрощує Вашу навігацію. Візуальна якість буде знижена, але чіткість підвищиться..",
    "Legal notice" : "Правові застереження",
    "Privacy policy" : "Політика конфіденційності",
    "Adjust the Nextcloud theme" : "Налаштуйте тему Nextcloud",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Для нас дуже важливо забезпечити доступ для всіх. Ми дотримуємось веб-стандартів і перевіряємо, щоб забезпечити зручність користування без комп'ютерної миші, а також за допомогую допоміжного програмного забезпечення, наприклад, програми зчитування з екрана. Ми прагнемо відповідати {guidelines} Правила доступу до веб-вмісту {linkend} 2.1 на рівні AA, а з темою високої контрастності навіть на рівні AAA.",
    "Open documentation" : "Відкрити документацію",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Оформлення дозволяє легко налаштувати зовнішній вигляд вашого сервера та підтримуваних клієнтів. Це будуть бачити всі користувачі.",
    "Name" : "Ім’я",
    "Reset to default" : "Скинути до типового",
    "Web link" : "Посилання",
    "https://…" : "https://…",
    "Slogan" : "Гасло",
    "Color" : "Колір",
    "Logo" : "Логотип",
    "Upload new logo" : "Завантажити новий логотип",
    "Login image" : "Зображення сторінки входу",
    "Upload new login background" : "Завантажити новий фон для сторінки входу",
    "Remove background image" : "Вилучити зображення тла",
    "Advanced options" : "Розширені налаштування",
    "Legal notice link" : "Посилання на правову інформацію",
    "Privacy policy link" : "Посилання на політику конфіденційності",
    "Header logo" : "Логотип заголовка",
    "Upload new header logo" : "Завантажити новий логотип заголовка",
    "Favicon" : "Піктограма сайту",
    "Upload new favicon" : "Завантажити нову піктограму",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Встановіть розширення Imagemagick PHP з підтримкою SVG-зображень, щоб автоматично генерувати іконки сайту на основі завантаженого логотипу та кольору."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
